@@ -1,8 +1,8 @@
 /*************************************************************************
 ** FontMap.cpp                                                          **
 **                                                                      **
-** This file is part of dvisvgm -- the DVI to SVG converter             **
-** Copyright (C) 2005-2014 Martin Gieseking <martin.gieseking@uos.de>   **
+** This file is part of dvisvgm -- a fast DVI to SVG converter          **
+** Copyright (C) 2005-2018 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -18,30 +18,23 @@
 ** along with this program; if not, see <http://www.gnu.org/licenses/>. **
 *************************************************************************/
 
-#include <config.h>
+#include <algorithm>
 #include <cstring>
 #include <fstream>
-#include <iostream>
 #include <limits>
 #include <vector>
-#include "CMap.h"
-#include "Directory.h"
-#include "FileFinder.h"
-#include "FontManager.h"
-#include "FontMap.h"
-#include "MapLine.h"
-#include "Message.h"
-#include "Subfont.h"
+#include "CMap.hpp"
+#include "Directory.hpp"
+#include "FileFinder.hpp"
+#include "FontManager.hpp"
+#include "FontMap.hpp"
+#include "MapLine.hpp"
+#include "Message.hpp"
+#include "Subfont.hpp"
+#include "utility.hpp"
 
 using namespace std;
 
-
-FontMap::~FontMap () {
-	for (Iterator it=_entries.begin(); it != _entries.end(); ++it)
-		delete it->second;
-}
-
-
 /** Returns the singleton instance. */
 FontMap& FontMap::instance() {
 	static FontMap fontmap;
@@ -55,8 +48,8 @@ FontMap& FontMap::instance() {
  *  @return true if file could be opened */
 bool FontMap::read (const string &fname, FontMap::Mode mode) {
 	ifstream ifs(fname.c_str());
-   if (!ifs)
-      return false;
+	if (!ifs)
+		return false;
 
 	int line_number = 1;
 	while (ifs) {
@@ -78,7 +71,7 @@ bool FontMap::read (const string &fname, FontMap::Mode mode) {
 				Message::wstream(false) << e.what() << '\n';
 			}
 		}
-      line_number++;
+		line_number++;
 	}
 	return true;
 }
@@ -87,9 +80,9 @@ bool FontMap::read (const string &fname, FontMap::Mode mode) {
 bool FontMap::read (const string &fname, char modechar) {
 	Mode mode;
 	switch (modechar) {
-		case '=': mode = FM_REPLACE; break;
-		case '-': mode = FM_REMOVE; break;
-		default : mode = FM_APPEND;
+		case '=': mode = Mode::REPLACE; break;
+		case '-': mode = Mode::REMOVE; break;
+		default : mode = Mode::APPEND;
 	}
 	return read(fname, mode);
 }
@@ -101,9 +94,9 @@ bool FontMap::read (const string &fname, char modechar) {
  *  @return true in case of success */
 bool FontMap::apply (const MapLine& mapline, FontMap::Mode mode) {
 	switch (mode) {
-		case FM_APPEND:
+		case Mode::APPEND:
 			return append(mapline);
-		case FM_REMOVE:
+		case Mode::REMOVE:
 			return remove(mapline);
 		default:
 			return replace(mapline);
@@ -118,9 +111,9 @@ bool FontMap::apply (const MapLine& mapline, FontMap::Mode mode) {
 bool FontMap::apply (const MapLine& mapline, char modechar) {
 	Mode mode;
 	switch (modechar) {
-		case '=': mode = FM_REPLACE; break;
-		case '-': mode = FM_REMOVE; break;
-		default : mode = FM_APPEND;
+		case '=': mode = Mode::REPLACE; break;
+		case '-': mode = Mode::REMOVE; break;
+		default : mode = Mode::APPEND;
 	}
 	return apply(mapline, mode);
 }
@@ -146,12 +139,12 @@ bool FontMap::read (const string &fname_seq) {
 			right = fname_seq.length();
 		}
 		if (!fname.empty()) {
-         if (!read(fname, modechar)) {
-            if (const char *path = FileFinder::lookup(fname, false))
-               found = found || read(path, modechar);
-            else
-               Message::wstream(true) << "map file " << fname << " not found\n";
-         }
+			if (!read(fname, modechar)) {
+				if (const char *path = FileFinder::instance().lookup(fname, false))
+					found = found || read(path, modechar);
+				else
+					Message::wstream(true) << "map file " << fname << " not found\n";
+			}
 		}
 		left = right+1;
 	}
@@ -164,25 +157,25 @@ bool FontMap::read (const string &fname_seq) {
  *  @param[in] mapline parsed font data
  *  @return true if data has been appended */
 bool FontMap::append (const MapLine &mapline) {
-	bool ret = false;
-   if (!mapline.texname().empty()) {
+	bool appended = false;
+	if (!mapline.texname().empty()) {
 		if (!mapline.fontfname().empty() || !mapline.encname().empty()) {
 			vector<Subfont*> subfonts;
 			if (mapline.sfd())
 				mapline.sfd()->subfonts(subfonts);
 			else
-				subfonts.push_back(0);
-			for (size_t i=0; i < subfonts.size(); i++) {
-				string fontname = mapline.texname()+(subfonts[i] ? subfonts[i]->id() : "");
-				Iterator it = _entries.find(fontname);
+				subfonts.push_back(nullptr);
+			for (Subfont *subfont : subfonts) {
+				string fontname = mapline.texname()+(subfont ? subfont->id() : "");
+				auto it = _entries.find(fontname);
 				if (it == _entries.end()) {
-					_entries[fontname] = new Entry(mapline, subfonts[i]);
-					ret = true;
+					_entries.emplace(fontname, util::make_unique<Entry>(mapline, subfont));
+					appended = true;
 				}
 			}
 		}
 	}
-	return ret;
+	return appended;
 }
 
 
@@ -191,7 +184,7 @@ bool FontMap::append (const MapLine &mapline) {
  *  @param[in] mapline parsed font data
  *  @return true if data has been replaced */
 bool FontMap::replace (const MapLine &mapline) {
-   if (mapline.texname().empty())
+	if (mapline.texname().empty())
 		return false;
 	if (mapline.fontfname().empty() && mapline.encname().empty())
 		return remove(mapline);
@@ -200,14 +193,14 @@ bool FontMap::replace (const MapLine &mapline) {
 	if (mapline.sfd())
 		mapline.sfd()->subfonts(subfonts);
 	else
-		subfonts.push_back(0);
-	for (size_t i=0; i < subfonts.size(); i++) {
-		string fontname = mapline.texname()+(subfonts[i] ? subfonts[i]->id() : "");
-		Iterator it = _entries.find(fontname);
+		subfonts.push_back(nullptr);
+	for (Subfont *subfont : subfonts) {
+		string fontname = mapline.texname()+(subfont ? subfont->id() : "");
+		auto it = _entries.find(fontname);
 		if (it == _entries.end())
-			_entries[fontname] = new Entry(mapline, subfonts[i]);
+			_entries.emplace(fontname, util::make_unique<Entry>(mapline, subfont));
 		else if (!it->second->locked)
-			*it->second = Entry(mapline, subfonts[i]);
+			*it->second = Entry(mapline, subfont);
 	}
 	return true;
 }
@@ -218,41 +211,41 @@ bool FontMap::replace (const MapLine &mapline) {
  *  @param[in] mapline parsed font data
  *  @return true if entry has been removed */
 bool FontMap::remove (const MapLine &mapline) {
-	bool ret = false;
-   if (!mapline.texname().empty()) {
+	bool removed = false;
+	if (!mapline.texname().empty()) {
 		vector<Subfont*> subfonts;
 		if (mapline.sfd())
 			mapline.sfd()->subfonts(subfonts);
 		else
-			subfonts.push_back(0);
-		for (size_t i=0; i < subfonts.size(); i++) {
-			string fontname = mapline.texname()+(subfonts[i] ? subfonts[i]->id() : "");
-			Iterator it = _entries.find(fontname);
+			subfonts.push_back(nullptr);
+		for (const Subfont *subfont : subfonts) {
+			string fontname = mapline.texname()+(subfont ? subfont->id() : "");
+			auto it = _entries.find(fontname);
 			if (it != _entries.end() && !it->second->locked) {
 				_entries.erase(it);
-				ret = true;
+				removed = true;
 			}
 		}
-   }
-   return ret;
+	}
+	return removed;
 }
 
 
 ostream& FontMap::write (ostream &os) const {
-	for (ConstIterator it=_entries.begin(); it != _entries.end(); ++it)
-		os << it->first << " -> " << it->second->fontname << " [" << it->second->encname << "]\n";
+	for (const auto &entry : _entries)
+		os << entry.first << " -> " << entry.second->fontname << " [" << entry.second->encname << "]\n";
 	return os;
 }
 
 
 /** Reads and evaluates all map files in the given directory.
- *  @param[in] path to directory containing the map files to be read */
+ *  @param[in] dirname path to directory containing the map files to be read */
 void FontMap::readdir (const string &dirname) {
 	Directory dir(dirname);
 	while (const char *fname = dir.read(Directory::ET_FILE)) {
 		if (strlen(fname) >= 4 && strcmp(fname+strlen(fname)-4, ".map") == 0) {
 			string path = dirname + "/" + fname;
-			read(path.c_str());
+			read(path);
 		}
 	}
 }
@@ -262,17 +255,17 @@ void FontMap::readdir (const string &dirname) {
  * @param[in] fontname name of font whose mapped name is retrieved
  * @returns name of mapped font */
 const FontMap::Entry* FontMap::lookup (const string &fontname) const {
-	ConstIterator it = _entries.find(fontname);
+	auto it = _entries.find(fontname);
 	if (it == _entries.end())
-		return 0;
-	return it->second;
+		return nullptr;
+	return it->second.get();
 }
 
 
 /** Sets the lock flag for the given font in order to avoid changing the map data of this font.
  *  @param[in] fontname name of font to be locked */
 void FontMap::lockFont (const string& fontname) {
-	Iterator it = _entries.find(fontname);
+	auto it = _entries.find(fontname);
 	if (it != _entries.end())
 		it->second->locked = true;
 }
@@ -281,19 +274,17 @@ void FontMap::lockFont (const string& fontname) {
 /** Removes all (unlocked) entries from the font map.
  *  @param[in] unlocked_only if true, only unlocked entries are removed */
 void FontMap::clear (bool unlocked_only) {
-   if (!unlocked_only)
-      _entries.clear();
-   else {
-      Iterator it=_entries.begin();
-      while (it != _entries.end()) {
-         if (it->second->locked)
-            ++it;
-         else {
-				delete it->second;
-            _entries.erase(it++);
-			}
-      }
-   }
+	if (!unlocked_only)
+		_entries.clear();
+	else {
+		auto it=_entries.begin();
+		while (it != _entries.end()) {
+			if (it->second->locked)
+				++it;
+			else
+				it = _entries.erase(it);
+		}
+	}
 }
 
 /////////////////////////////////////////////////
