@@ -1,8 +1,8 @@
 /*************************************************************************
 ** MiKTeXCom.cpp                                                        **
 **                                                                      **
-** This file is part of dvisvgm -- the DVI to SVG converter             **
-** Copyright (C) 2005-2015 Martin Gieseking <martin.gieseking@uos.de>   **
+** This file is part of dvisvgm -- a fast DVI to SVG converter          **
+** Copyright (C) 2005-2018 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -18,25 +18,22 @@
 ** along with this program; if not, see <http://www.gnu.org/licenses/>. **
 *************************************************************************/
 
-#include <config.h>
-#include <stdio.h>
 #include <comdef.h>
 #include <string>
-#include "MessageException.h"
-#include "MiKTeXCom.h"
-#include "macros.h"
+#include "MessageException.hpp"
+#include "MiKTeXCom.hpp"
 
 using namespace std;
 
 
 /** Constructs a COM object representing a MiKTeX session. */
-MiKTeXCom::MiKTeXCom () : _session(0) {
-	if (FAILED(CoInitialize(0)))
+MiKTeXCom::MiKTeXCom () : _session() {
+	if (FAILED(CoInitialize(nullptr)))
 		throw MessageException("COM library could not be initialized\n");
 	// try to initialize the MiKTeX session object
 #ifdef _MSC_VER
 	HRESULT hres = _session.CreateInstance(L"MiKTeX.Session");
-#elif defined(__WIN64__)
+#elif defined(_WIN64)
 	HRESULT hres = CoCreateInstance(CLSID_MiKTeXSession2_9, 0, CLSCTX_LOCAL_SERVER, IID_ISession2, (void**)&_session);
 #else
 	HRESULT hres = CoCreateInstance(CLSID_MiKTeXSession2_9, 0, CLSCTX_INPROC_SERVER, IID_ISession2, (void**)&_session);
@@ -55,7 +52,7 @@ MiKTeXCom::~MiKTeXCom () {
 #else
 		_session->Release();
 #endif
-		_session = 0; // prevent automatic call of Release() after CoUninitialize()
+		_session = nullptr; // prevent automatic call of Release() after CoUninitialize()
 	}
 	CoUninitialize();
 }
@@ -106,7 +103,7 @@ const char* MiKTeXCom::findFile (const char *fname) {
 			ret = _bstr_t(path);
 			return ret.c_str();
 		}
-		return 0;
+		return nullptr;
 	}
 	catch (_com_error &e) {
 		throw MessageException((const char*)e.Description());
