@@ -1,8 +1,8 @@
 /*************************************************************************
 ** StreamReaderTest.cpp                                                 **
 **                                                                      **
-** This file is part of dvisvgm -- the DVI to SVG converter             **
-** Copyright (C) 2005-2015 Martin Gieseking <martin.gieseking@uos.de>   **
+** This file is part of dvisvgm -- a fast DVI to SVG converter          **
+** Copyright (C) 2005-2018 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -22,17 +22,19 @@
 #include <fstream>
 #include <sstream>
 #include <string>
-#include "CRC32.h"
-#include "StreamReader.h"
+#include "CRC32.hpp"
+#include "StreamReader.hpp"
 
 using namespace std;
 
 TEST(StreamReaderTest, readString) {
 	string str1 = "dvisvgm converts DVI files to SVG.";
 	istringstream iss(str1);
+	ASSERT_TRUE(bool(iss));
 	StreamReader reader(iss);
 	string str2 = reader.readString(iss.str().length());
 	EXPECT_EQ(str1, str2);
+	iss.clear();
 	iss.str(str1);
 	str2 = reader.readString();
 	EXPECT_EQ(str1, str2);
@@ -42,15 +44,17 @@ TEST(StreamReaderTest, readString) {
 TEST(StreamReaderTest, readStringCRC) {
 	string str1 = "dvisvgm converts DVI files to SVG.";
 	istringstream iss(str1);
+	ASSERT_TRUE(bool(iss));
 	StreamReader reader(iss);
 	CRC32 crc;
 	string str2 = reader.readString(iss.str().length(), crc);
 	EXPECT_EQ(str1, str2);
-	EXPECT_EQ(crc.get(), 0x7c4ef359);
+	EXPECT_EQ(crc.get(), 0x7c4ef359u);
+	iss.clear();
 	iss.str(str1);
 	crc.reset();
 	str2 = reader.readString(crc, false);
-	EXPECT_EQ(crc.get(), 0x7c4ef359);
+	EXPECT_EQ(crc.get(), 0x7c4ef359u);
 }
 
 
@@ -58,8 +62,8 @@ TEST(StreamReaderTest, readUnsigned) {
 	string str = "\x01\x02\x03\x04";
 	istringstream iss(str);
 	StreamReader reader(iss);
-	UInt32 val = reader.readUnsigned(4);
-	EXPECT_EQ(val, 0x01020304);
+	uint32_t val = reader.readUnsigned(4);
+	EXPECT_EQ(val, 0x01020304u);
 }
 
 
@@ -68,9 +72,9 @@ TEST(StreamReaderTest, readUnsignedCRC) {
 	istringstream iss(str);
 	StreamReader reader(iss);
 	CRC32 crc;
-	UInt32 val = reader.readUnsigned(4, crc);
-	EXPECT_EQ(val, 0x01020304);
-	EXPECT_EQ(crc.get(), 0xb63cfbcd);
+	uint32_t val = reader.readUnsigned(4, crc);
+	EXPECT_EQ(val, 0x01020304u);
+	EXPECT_EQ(crc.get(), 0xb63cfbcdu);
 }
 
 
@@ -78,8 +82,8 @@ TEST(StreamReaderTest, readSigned) {
 	string str = "\xff\xee\xdd\xcc";
 	istringstream iss(str);
 	StreamReader reader(iss);
-	Int32 val = reader.readSigned(4);
-	EXPECT_EQ(val, 0xffeeddcc);
+	int32_t val = reader.readSigned(4);
+	EXPECT_EQ(val, int32_t(0xffeeddcc));
 }
 
 
@@ -88,9 +92,9 @@ TEST(StreamReaderTest, readSignedCRC) {
 	istringstream iss(str);
 	StreamReader reader(iss);
 	CRC32 crc;
-	Int32 val = reader.readSigned(4, crc);
-	EXPECT_EQ(val, 0xffeeddcc);
-	EXPECT_EQ(crc.get(), 0xfa79118e);
+	int32_t val = reader.readSigned(4, crc);
+	EXPECT_EQ(val, int32_t(0xffeeddcc));
+	EXPECT_EQ(crc.get(), 0xfa79118eu);
 }
 
 
@@ -98,7 +102,7 @@ TEST(StreamReaderTest, readBytes) {
 	string str = "\xff\xee\xdd\xcc";
 	istringstream iss(str);
 	StreamReader reader(iss);
-	vector<UInt8> bytes(4);
+	vector<uint8_t> bytes(4);
 	memset(&bytes[0], 0, 4);
 	reader.readBytes(3, bytes);
 	EXPECT_EQ(bytes[0], 0xff);
@@ -112,7 +116,7 @@ TEST(StreamReaderTest, readBytesCRC) {
 	string str = "\xff\xee\xdd\xcc";
 	istringstream iss(str);
 	StreamReader reader(iss);
-	vector<UInt8> bytes(4);
+	vector<uint8_t> bytes(4);
 	memset(&bytes[0], 0, 4);
 	CRC32 crc;
 	reader.readBytes(3, bytes, crc);
@@ -120,9 +124,9 @@ TEST(StreamReaderTest, readBytesCRC) {
 	EXPECT_EQ(bytes[1], 0xee);
 	EXPECT_EQ(bytes[2], 0xdd);
 	EXPECT_EQ(bytes[3], 0);
-	EXPECT_EQ(crc.get(), 0x68ab9f15);
+	EXPECT_EQ(crc.get(), 0x68ab9f15u);
 	int byte = reader.readByte(crc);
 	EXPECT_EQ(byte, 0xcc);
-	EXPECT_EQ(crc.get(), 0x2d652e62);
+	EXPECT_EQ(crc.get(), 0x2d652e62u);
 }
 
